[see also]
The complete GNU mailutils documentation is maintained as a Texinfo
manual. If the
.B mailutils-doc
package is installed, the command
.IP
.B info mailutils
.PP
should give you access to the complete manual.
.br
You can also find this manual online in the GNU mailutils webpage:
.br
https://www.gnu.org/software/mailutils/manual/index.html.
.br
Please note this manpage was automatically generated by the
Debian mailutils packagers. Do not file bugs for its content to the
GNU Mailutils upstream authors.
